@@ -1,5 +1,8 @@
 """Teamocil data fixtures for import_teamocil tests, 1st test."""
-from .. import utils as test_utils
+
+from __future__ import annotations
+
+from tests.fixtures import utils as test_utils
 
 teamocil_yaml = test_utils.read_workspace_file("import_teamocil/test1.yaml")
 teamocil_conf = {
