@@ -1,7 +1,10 @@
 """YAML examples of expansion of tmuxp configurations from shorthand style."""
+
+from __future__ import annotations
+
 import pathlib
 
-from .. import utils as test_utils
+from tests.fixtures import utils as test_utils
 
 
 def unexpanded_yaml() -> str:
